searchData={"items":[{"type":"module","title":"Without","doc":"`Without` is a tiny module to ease the usage of result tuple.\n\nUsing `case` once is convenient, using it more than twice, makes the code less readable, consider this snippet\n\n```\ncase find_user(email) do\n  {:ok, user} -> \n    case find_friends(user) do\n      {:ok, friends} -> \"#{user} is friends of #{Enum.join(\",\", friends)}\"\n      {:error, :friends_not_found} -> \"#{user} doesn't have any friends\"\n    end\n  {:error, :user_not_found} -> \"user not found\"\nend\n```\n\nYou might ask maybe `with` could help on that?\n```\nwith {:ok, user} <- find_user(email),\n     {:ok, friends} <- find_friends(user) do\n    \"#{user} is friends of #{Enum.join(\",\", friends)}\"\n\nelse\n  {:error, :user_not_found} -> \"user not found\"\n  {:error, :friends_not_found} -> \"#{user} doesn't have any friends\"\nend\n```\nBut the issue here is that variable `user` is not available in the last else case!\n\n\nNow that you feel the pain, let me introduce you to `Without`!\n```\nemail\n|> Without.fmap_ok(&find_user/1, assign: :user)\n|> Without.fmap_ok(&find_friends/1)\n|> Without.fmap_error(fn error, assigns ->\n  case error do\n  :user_not_found -> \"user not found\"\n  :friends_not_found, assigns -> \"#{assigns[:user]} doesn't have any friends\" \nend)\n|> Without.fresult\n```\n\nIf you are a functional programming aficionado, it might resemble monadic error handling.","ref":"Without.html"},{"type":"function","title":"Without.finit/1","doc":"","ref":"Without.html#finit/1"},{"type":"function","title":"Without.fmap_error/2","doc":"","ref":"Without.html#fmap_error/2"},{"type":"function","title":"Without.fmap_ok/3","doc":"","ref":"Without.html#fmap_ok/3"},{"type":"function","title":"Without.fresult/1","doc":"","ref":"Without.html#fresult/1"},{"type":"type","title":"Without.error/0","doc":"","ref":"Without.html#t:error/0"},{"type":"type","title":"Without.map_func/0","doc":"","ref":"Without.html#t:map_func/0"},{"type":"type","title":"Without.ok/0","doc":"","ref":"Without.html#t:ok/0"},{"type":"type","title":"Without.options/0","doc":"","ref":"Without.html#t:options/0"},{"type":"type","title":"Without.result/0","doc":"","ref":"Without.html#t:result/0"},{"type":"type","title":"Without.t/0","doc":"","ref":"Without.html#t:t/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}